@@ -1,18 +1,24 @@
-import pygamergui.window as window
-import pygamergui.tools as tools
+from pygamergui import window
+from pygamergui import tools
+import pygamergui
 from rich import print,inspect
-def b1test():
-    print("b1")
+
+def b1test(args):
+    t1.text="use"
+def b2test(args):
+    t1.text="hello"
+
 
 b1=tools.simple_button(target=b1test,
                   text='use',
                   fg='white',
                   w=75,
                   h=50,
-                  color=(0,175,250)
+                  color=(0,175,250),
+                  args=[1]
                   )
 
-b2=tools.simple_button(target=b1test,
+b2=tools.simple_button(target=b2test,
                   fg='white',
                   text="hello",
                   w=100,
@@ -43,5 +49,4 @@ def update():
 
     a=s1.show(windowm)
 windowm=window.app(title='test',bgcolor=(40,40,40),target=update,update_rate=10)
-windowm.run()
-
+windowm.run()
\ No newline at end of file
